/******************************************************************************
 * @file     V2M-P1.h
 * @brief    Arm Motherboard Express V2M-P1 registers
 * @version  V1.0.0
 * @date     10. May 2019
 *
 * @note
 *
 ******************************************************************************/
/*
 * Copyright (c) 2009-2019 Arm Limited. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

 #ifndef __V2M_P1_H__
#define __V2M_P1_H__

#include "RTE_Components.h"             /* Component selection */
#include CMSIS_device_header

typedef struct
{
  __IOM  uint32_t SYS_ID;               /* System Identifier */
  __IOM  uint32_t SYS_SW;               /* Bits [7:0] are the soft user switches */
  __IOM  uint32_t SYS_LED;              /* Bits [7:0] map to user LEDs */
  RESERVED(0[6], uint32_t)
  __IM   uint32_t SYS_100HZ;            /* 100Hz Counter Register */
  RESERVED(1[2], uint32_t)
  __IOM  uint32_t SYS_FLAGS;            /* Flag Registers */
  __OM   uint32_t SYS_FLAGSCLR;         /* Flag Registers */
  __IOM  uint32_t SYS_NVFLAGS;          /* Non-volatile Flag Registers */
  __OM   uint32_t SYS_NVFLAGSCLR;       /* Non-volatile Flag Registers */
  RESERVED(2[2], uint32_t)
  __IM   uint32_t SYS_MCI;              /* MCI status and control register */
  __IOM  uint32_t SYS_FLASH;            /* Controls write protection of flash devices */
  RESERVED(3[2], uint32_t)
  __IOM  uint32_t SYS_CFGSW;            /* Bits [7:0] are the soft configuration switches */
  __IM   uint32_t SYS_24MHZ;            /* 32-bit counter clocked at 24MHz */
  __IOM  uint32_t SYS_MISC;             /* Miscellaneous control flags */
  __IOM  uint32_t SYS_DMA;              /* DMA Channel Selection Register */
  RESERVED(4[7], uint32_t)
  __IOM  uint32_t SYS_PROCID0;          /* Core or cluster type at the CoreTile Express Site 1 */
  __IOM  uint32_t SYS_PROCID1;          /* Core or cluster type at the CoreTile Express Site 2 */
  RESERVED(5[6], uint32_t)
  __IOM  uint32_t SYS_CFGDATA;          /* System Configuration Register */
  __IOM  uint32_t SYS_CFGCTRL;          /* Configuration Control Register */
  __IOM  uint32_t SYS_CFGSTAT;          /* Configuration Status Register */
} STATUS_SYSTEM_Type;

#if (__CORTEX_A == 5U)
  #define STATUS_SYSTEM ((STATUS_SYSTEM_Type *) VE_A5_MP_SYSTEM_REG_BASE)
#elif (__CORTEX_A == 7U)
  #define STATUS_SYSTEM ((STATUS_SYSTEM_Type *) VE_A7_MP_SYSTEM_REG_BASE)
#elif (__CORTEX_A == 9U)
  #define STATUS_SYSTEM ((STATUS_SYSTEM_Type *) VE_A9_MP_SYSTEM_REG_BASE)
#endif

#endif  // __V2M_P1_H__
